@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use utf8;
 # ABSTRACT: Twitter when you release with Dist::Zilla
-our $VERSION = '0.025'; # VERSION
+our $VERSION = '0.026'; # VERSION
 
 use Dist::Zilla 4 ();
 use Moose 0.99;
@@ -254,7 +254,7 @@ Dist::Zilla::Plugin::Twitter - Twitter when you release with Dist::Zilla
 
 =head1 VERSION
 
-version 0.025
+version 0.026
 
 =head1 SYNOPSIS
 
@@ -358,21 +358,19 @@ __END__
 
 =head1 AVAILABILITY
 
-The project homepage is L<http://metacpan.org/release/Dist-Zilla-Plugin-Twitter/>.
-
 The latest version of this module is available from the Comprehensive Perl
 Archive Network (CPAN). Visit L<http://www.perl.com/CPAN/> to find a CPAN
 site near you, or see L<https://metacpan.org/module/Dist::Zilla::Plugin::Twitter/>.
 
 =head1 SOURCE
 
-The development version is on github at L<http://github.com/doherty/Dist-Zilla-Plugin-Twitter>
-and may be cloned from L<git://github.com/doherty/Dist-Zilla-Plugin-Twitter.git>
+The development version is on github at L<http://github.com/dagolden/dist-zilla-plugin-twitter>
+and may be cloned from L<git://github.com/dagolden/dist-zilla-plugin-twitter.git>
 
 =head1 BUGS AND LIMITATIONS
 
 You can make new bug reports, and view existing ones, through the
-web interface at L<https://github.com/doherty/Dist-Zilla-Plugin-Twitter/issues>.
+web interface at L<https://github.com/dagolden/dist-zilla-plugin-twitter/issues>.
 
 =head1 AUTHORS
 
